bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 1. Aventiure
___________________________________________________
| ### ns ist in alten mæren wnders vil geseit ### von helden lobebærn von grozzer chvonheit ### von frovden hochgeziten von weinen vn– von klagen ### von chvoner rechen strite mvget ir nv wunder hoeren sagen ### Ez wuohs in Burgonden ein schoene magedin ### daz in allen landen niht schoeners mohte sin ### Chriemhilt was si geheizzen vnde was ein schoene wip ### darumbe mvosen degene vil verliesen den lip
###### 3 | ### Der minnechlichen meide trvoten wol gezam ### in mvote kvoner recken niemen was ir gram ### ane mazen schoene so was ir edel lip ### der ivnchfrovwen tugende zierten anderiv wip
###### 4 | ### Ir phlagen dri kvnige edel vnde rich ### Gvnthere vnde Gernot die recken lobelich ### vnde Giselher der ivnge ein voz erwelter degen ### div frovwe was ir swester die fvrsten hetens in ir pflegen
###### 5 | ### Die herren warn milte von arte hoh geborn ### mit krefte vnmazzen kvene die recken voz erkorn ### da zen Burgonden so was ir lant genant ### si frvmden starkiv wnder sit in Ezelen lant
###### 6 | ### Ze Wornitz bi dem Rine si wonden mit ir kraft ### in diende von ir landen vil stolziv riterschaft ### mit stoltzlichen eren vnz an ir endes zit ### sit stvrben si iamerliche von zweier edelen frovwen nit
###### 7 | ### Ein richiv kvniginne frov vote ir mvoter hiez ### ir vater hiez Danchrat der in div erbe liez ### sit nach sime lebne ein ellens richer man ### der ovch in siner iugende grozzer eren vil gewan
###### 8 | ### Die dri kvnige waren als ich gesaget han ### von vi hohem ellen in warn vndertan ### ovch die besten rechen von den man hat gesaget ### stark vnde vil chvone in allen striten vnuerzaget
###### 9 | ### Daz was von Tronyn Hagene vnd ovch der bruoder sin ### Danchwart der vil snelle vnde von Mecen Ortwin ### die zwene marchgrauen Gere vnde Eckewart ### Volcker von Alzaye mit ganzen ellen wol bewart
###### 10 | ### Rvomol der kvchen meister ein voz erwelter degen ### Sindolt und Hvonolt dise herren mvosen pflegen ### des houes vnd der eren der drier kvnige man ### si heten noch manigen reken der ich genennen niht <en>
###### 11 | ### Danchwart der was marschalch do was der neu ### trvhsætze des kvniges von Mezen Ortwin ### Sindolt der was schenche ein voz erwelter degen ### Hvnolt was kamerære si chvnden grozzer eren pflegen
###### 12 | ### Von des houes krefte vnde von ir witen kraft ### von ir vil hohen werdecheit vnde von ir riterschaft ### der die herren pflagen mit frovden al ir leben ### des enchvnde iu ze ware niemen gar ein ende geben
###### 13 | ### Ez trovmde Chriemhilde in tvgenden der si pflach ### wie si einen valchen wilden zuge manigen tach [1b] ### den in zwene arn erchlimmen daz si daz mvosde sehen ### ir enchvnde in dirre werlde nimmer leider sin geschehen
###### 14 | ### Den trovm si do sagete ir mvoter voten ### sin kvnde in baz descheiden niht der gvoten ### der ualche den <du> ziuhest daz ist ein edel man ### in welle got behvoten du mvost in schiere verlorn han
###### 15 | ### Waz saget ir mir von manne vil liebiv mvoter min ### ane reken minne wil ich immer sin ### svs schoene wil ich beliben vnz an minen tot ### daz ich sol von manne nimmer gewinnen deheine not
###### 16 | ### Nv verspriche ez niht ze sere sprach aber ir mvoter do ### solt dv immer herzenliche zer werlde werden fro ### daz geschiht von mannes minne dv wirst ein schoene wip ### obe dir got noch gefueget eins rehten guotes riter lip
###### 17 | ### Die rede lat beliben sprach si vrovwe min ### ez ist ein manegem wibe vil diche worden schin ### wie liebe mit leide ze iungest lonen kan ### ich sol si miden beidiv son chan mir nimmer missegan
###### 18 | ### In ir vil hohen tvgenden der si schoene pflack ### lebte diu maget edele vil manegen lieben tach ### daz si wesse niemen den minnen wolde ir lip ### sit wart si mit eren eins vil gvoten riters wip
###### 19 | ### Der was der selbe valche den si in ir <trovme> sach ### den ir beschiet ir mvoter wie ser si daz rach ### an ir næhsten magen die in slvogen sint ### dvrch sin eins sterben starp vil maneger muoter kint

<<< Übersicht <<< vorige Seite nächste Seite >>>